### CELL ANALYSIS TOOLS

A library for loading, processing and summarizing single cell imaging data.

---
#### Dependencies

* numpy
* tifffile 
* from pathlib import Path
* read_roi
* os
* matplotlib
* re
* skimage
* pandas as pd

---
#### Installation

To install this library change directory to the root of the cell_analysis_tools folder then execute:

`$ pip install -e .`

you should then be able to import it into your script


`import cell_analysis_tools`
